File {
  owner => root,
  group => root,
  mode => 0644,
}

Service {
  hasstatus => true,
  hasrestart => true,
}

file { 
  ["/etc/puppet/rack", "/etc/puppet/rack/public"]:
    ensure => directory,
    mode => 0755;
  "/etc/puppet/rack/config.ru":
    ensure => present,
    source => "puppet:///modules/rack/config.ru",
    mode => 0644,
    owner => puppet;
  "/etc/httpd/conf.d/puppetmaster.conf":
    ensure => present,
    source => "puppet:///modules/rack/apache2.conf",
    require => [File["/etc/puppet/rack/config.ru"], File["/etc/puppet/rack/public"], Package["httpd"], Package["mod_passenger"]],
    notify => Augeas["httpd_conf"];
}
if versioncmp($puppetversion, "2.6.0") < 0 {
  $master = "puppetmasterd"
} else {
  $master = "master"
}
augeas { 
  "puppetmaster_ssl": 
    context => "/files/etc/puppet/puppet.conf/$master",
    changes => [
      "set ssl_client_header SSL_CLIENT_S_DN",
      "set ssl_client_verify_header SSL_CLIENT_VERIFY"
    ],
    require => Package["puppet-server"];
  "httpd_conf":
    context => "/files/etc/httpd/conf.d/puppetmaster.conf/VirtualHost/",
    changes => [
      "set *[self::directive='SSLCertificateFile']/arg /var/lib/puppet/ssl/certs/${fqdn}.pem",
      "set *[self::directive='SSLCertificateKeyFile']/arg /var/lib/puppet/ssl/private_keys/${fqdn}.pem",
    ],
    require => File["/etc/httpd/conf.d/puppetmaster.conf"],
    notify => Service["httpd"];
}

package { ["rubygem-rack", "mod_passenger", "puppet-server"]:
  ensure => installed,
  provider => "yum"
}

service { 
  "httpd":
    require => Package["httpd"];
  "puppetmaster":
    require => Package["puppet-server"],
    ensure => "stopped",
    enable => "false";
}

case $lsbdistid {
  "RedHat","CentOS","Fedora": {
    package { ["httpd", "httpd-devel", "mod_ssl"]:
      ensure => installed,
      provider => "yum"
    }
  }
}

notice("Puppet configuration for Phusion Passenger.")
notice("-------------------------------------------")
